#
# spec file for package multitail
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           multitail
Version:        6.4.2
Release:        lp152.3.6
Summary:        Tail Multiple Files
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            https://www.vanheusden.com/multitail/
Source:         https://www.vanheusden.com/multitail/%{name}-%{version}.tgz
# patch from https://sources.gentoo.org/cgi-bin/viewvc.cgi/gentoo-x86/app-text/multitail/files/
Patch0:         multitail-6.4.1-gentoo.patch
Patch3:         multitail-fix_missing_proto_do_check_for_mail.patch
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
MultiTail lets you view one or multiple files like the original
tail program.

The difference is that it creates multiple windows on your console
(with ncurses). Merging of 2 or even more logfiles is possible.

It can also use colors while displaying the logfiles (through
regular expressions), for faster recognition of what is important
and what not. It can also filter lines (again with regular
expressions). It has interactive menus for editing given regular
expressions and deleting and adding windows. One can also have
windows with the output of shell scripts and other software. When
viewing the output of external software, MultiTail can mimic the
functionality of tools like 'watch' and such.

%prep
%setup -q
%patch0 -p1
%patch3

sed -i 's/\.new//g' Makefile
sed -i 's|%{_sysconfdir}/%{name}|%{_datadir}/%{name}|g' "%{name}.conf"

%build
export CFLAGS="%{optflags} -I%{_includedir}/ncurses"
#as there is no .pc for ncurses in some older releases, specify manually
export LDFLAGS="-lpanelw -lncursesw "
make %{?_smp_mflags} \
    PKG_CONFIG="pkg-config" \
    UTF8_SUPPORT=yes \
    CONFIG_FILE="%{_sysconfdir}/%{name}.conf"

%install
%make_install

# docs are shipped already
rm -fr %{buildroot}%{_datadir}/doc/%{name}-%{version}

%files
%doc *.txt manual*.html
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%dir %{_sysconfdir}/%{name}
%{_sysconfdir}/%{name}/colors-example.pl
%{_sysconfdir}/%{name}/colors-example.sh
%{_sysconfdir}/%{name}/convert-geoip.pl
%{_sysconfdir}/%{name}/convert-simple.pl

%changelog
* Wed Feb  7 2018 avindra@opensuse.org
- Update to 6.4.2
  * Marker-line, tabs and allow to map delete as backspace
- use https urls
- cleanup with spec-cleaner
- other spec cleanups
  * simplify install
  * remove no no longer needed sed and chmod
* Fri Aug  7 2015 mpluskal@suse.com
- Update to 6.4.1
  * no changelog provided
- Drop unreferrenced multitail-6.0-as-needed.patch
- Add multitail-6.4.1-gentoo.patch
- Add multitail-fix_missing_proto_do_check_for_mail.patch
* Thu Feb 13 2014 pascal.bleser@opensuse.org
- update to 6.2:
  * fixes -q/-Q (which automatically create windows by given search-criteria)
- dropped multitail-remove_date.patch, fixed upstream
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 6.0: adds UTF-8 support
- dropped patch multitail-remove_unused_variables.patch, was a
  nightmare to maintain
* Fri Jun 21 2013 pascal.bleser@opensuse.org
- update to 5.2.13
  (no release notes available)
* Mon Mar 25 2013 pascal.bleser@opensuse.org
- update to 5.2.12
  (no release notes available)
* Thu Nov 22 2012 pascal.bleser@opensuse.org
- update to 5.2.10:
  * adds -N which sets the initial tail lines count for all following inputs
  * configuration file parameter min_n_bufferlines was ignored
  * added colorscheme for 'ADB-logging' (Android)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- add IPv6 support for sending to a syslog server and receiving syslog events
- update to 5.2.9:
  * fixes a segfault which happened when searching for strings with printf
    escapes in them (e.g., %%n)
* Fri Apr 15 2011 pascal.bleser@opensuse.org
- update to 5.2.8:
  * handle sources that disappear before reading more gracefully
  * no longer segfault when a file is truncated
* Wed Jan 19 2011 pascal.bleser@opensuse.org
- update to 5.2.7:
  * a fix for missing home directories failures
* Thu Feb 18 2010 pascal.bleser@opensuse.org
- update to 5.2.6:
  * fixes a segfault bug in the "scrollback" functionality
* Sun Feb 14 2010 pascal.bleser@opensuse.org
- copied to openSUSE Build Service
* Sun Feb 14 2010 toni@links2linux.de
- Update to multitail-5.2.5
- This version handles ANSI codes in logfiles more gracefully when using the
  "scrollback" functionality. Of course, you still need to add the "-cT ansi"
  switch for that.
* Mon May 19 2008 toni@links2linux.de
- Update to multitail-5.2.2
* Wed Feb 20 2008 toni@links2linux.de
- Update to multitail-5.2.1
* Mon Jul  9 2007 toni@links2linux.de
- Update to multitail-5.2.0
* Fri Jul  6 2007 toni@links2linux.de
- Update to multitail-5.1.2
* Mon Jun 18 2007 toni@links2linux.de
- Update to multitail-5.1.1
* Sat Jun  9 2007 toni@links2linux.de
- Update to multitail-5.1.0
* Fri Jun  1 2007 toni@links2linux.de
- Update to multitail-5.0.4
* Thu May 10 2007 toni@links2linux.de
- Update to multitail-5.0.3
* Wed May  2 2007 toni@links2linux.de
- Update to multitail-5.0.2
* Thu Apr 26 2007 toni@links2linux.de
- Update to multitail-5.0.1
* Fri Apr  6 2007 toni@links2linux.de
- Update to multitail-5.0.0
* Tue Apr  3 2007 toni@links2linux.de
- Update to multitail-4.3.7
* Thu Mar 29 2007 toni@links2linux.de
- Update to multitail-4.3.6
* Mon Mar 26 2007 toni@links2linux.de
- Update to multitail-4.3.5
* Tue Mar 20 2007 toni@links2linux.de
- Update to multitail-4.3.4
* Sun Mar 11 2007 toni@links2linux.de
- Update to multitail-4.3.3
* Wed Mar  7 2007 toni@links2linux.de
- Update to multitail-4.3.2
* Tue Feb 27 2007 toni@links2linux.de
- Update to multitail-4.3.1
* Tue Jan 16 2007 toni@links2linux.de
- Update to multitail-4.3.0
* Mon Sep 18 2006 toni@links2linux.de
- build for packman
* Fri Sep  8 2006 oc2pus@arcor.de 4.2.0-0.oc2pus.1
- Update to multitail-4.2.0
* Fri Aug 18 2006 oc2pus@arcor.de 4.1.2-0.oc2pus.1
- Update to multitail-4.1.2
* Fri Aug  4 2006 oc2pus@arcor.de 4.1.1-0.oc2pus.1
- Update to multitail-4.1.1
* Wed Jul 12 2006 oc2pus@arcor.de 4.1.0-0.oc2pus.1
- Update to multitail-4.1.0
* Wed Jun 14 2006 oc2pus@arcor.de 4.0.6-0.oc2pus.1
- Update to multitail-4.0.6
* Sat Jun 10 2006 oc2pus@arcor.de 4.0.5-0.oc2pus.1
- Update to multitail-4.0.5
* Mon May 22 2006 oc2pus@arcor.de 4.0.4-0.oc2pus.1
- Update to multitail-4.0.4
* Tue Apr 18 2006 oc2pus@arcor.de 4.0.3-0.oc2pus.1
- Update to multitail-4.0.3
* Thu Apr 13 2006 oc2pus@arcor.de 4.0.0-0.oc2pus.1
- Update to multitail-4.0.0
* Tue Apr  4 2006 oc2pus@arcor.de 3.9.15-0.oc2pus.1
- Update to multitail-3.9.15
* Thu Mar 30 2006 oc2pus@arcor.de 3.9.14.2-0.oc2pus.1
- Update to multitail-3.9.14.2
* Tue Mar 28 2006 oc2pus@arcor.de 3.9.14.1-0.oc2pus.1
- Update to multitail-3.9.14.1
* Wed Mar 22 2006 oc2pus@arcor.de 3.9.13-0.oc2pus.1
- Update to multitail-3.9.13
* Wed Mar 15 2006 oc2pus@arcor.de 3.9.12-0.oc2pus.1
- Update to multitail-3.9.12
* Sun Mar 12 2006 oc2pus@arcor.de 3.9.11-0.oc2pus.1
- Update to multitail-3.9.11
* Sun Mar  5 2006 oc2pus@arcor.de 3.9.10-0.oc2pus.1
- Update to multitail-3.9.10
* Tue Feb 28 2006 oc2pus@arcor.de 3.9.9-0.oc2pus.1
- Update to multitail-3.9.9
* Sun Feb 26 2006 oc2pus@arcor.de 3.9.8-0.oc2pus.1
- Update to multitail-3.9.8
* Thu Feb 23 2006 oc2pus@arcor.de 3.9.7-0.oc2pus.1
- Update to multitail-3.9.7
* Mon Feb 20 2006 oc2pus@arcor.de 3.9.6-0.oc2pus.1
- Update to multitail-3.9.6
* Tue Feb 14 2006 oc2pus@arcor.de 3.9.5-0.oc2pus.1
- Update to multitail-3.9.5
* Mon Jan 30 2006 oc2pus@arcor.de 3.9.4-0.oc2pus.1
- Update to multitail-3.9.4
* Sun Jan 29 2006 oc2pus@arcor.de 3.9.3-0.oc2pus.1
- Update to multitail-3.9.3
* Fri Jan 27 2006 oc2pus@arcor.de 3.9.2-0.oc2pus.1
- Update to multitail-3.9.2
* Fri Jan 13 2006 oc2pus@arcor.de 3.8.4-0.oc2pus.1
- Update to multitail-3.8.4
* Wed Jan  4 2006 oc2pus@arcor.de 3.8.3-0.oc2pus.1
- Update to multitail-3.8.3
* Mon Jan  2 2006 oc2pus@arcor.de 3.8.2-0.oc2pus.1
- Update to multitail-3.8.2
* Thu Dec 29 2005 oc2pus@arcor.de 3.8.1-0.oc2pus.1
- Update to multitail-3.8.1
* Wed Dec 28 2005 oc2pus@arcor.de 3.8.0-0.oc2pus.1
- Update to multitail-3.8.0
* Fri Dec 16 2005 oc2pus@arcor.de 3.7.6-0.oc2pus.1
- Update to multitail-3.7.6
* Thu Dec  8 2005 oc2pus@arcor.de 3.7.5-0.oc2pus.1
- Update to multitail-3.7.5
- removed patches
* Sun Nov 27 2005 oc2pus@arcor.de 3.7.4-0.oc2pus.1
- Update to multitail-3.7.4
* Fri Nov 18 2005 oc2pus@arcor.de 3.7.3-0.oc2pus.2
- rebuild SuSE-10
* Sat Oct 29 2005 oc2pus@arcor.de 3.7.3-0.oc2pus.1
- Update to multitail-3.7.3
* Sat Oct 22 2005 oc2pus@arcor.de 3.7.2-0.oc2pus.1
- Update to multitail-3.7.2
* Sun Aug 28 2005 oc2pus@arcor.de 3.6.1-0.oc2pus.1
- Update to multitail-3.6.1
- repacked as tar.bz2
* Thu Jul 14 2005 oc2pus@arcor.de 3.5.7-0.oc2pus.1
- Update to multitail-3.5.7
* Fri Jul  1 2005 oc2pus@arcor.de 3.5.5-0.oc2pus.1
- Update to multitail-3.5.5
* Mon Jun  6 2005 oc2pus@arcor.de 3.5.4-0.oc2pus.1
- Update to multitail-3.5.4
- strip binary
* Thu Mar 17 2005 oc2pus@arcor.de 3.5.2-0.oc2pus.1
- Update to multitail-3.5.2
* Sat Feb 26 2005 oc2pus@arcor.de 3.5.1-0.oc2pus.1
- Update to multitail-3.5.1
* Thu Feb 24 2005 oc2pus@arcor.de 3.4.7-0.oc2pus.1
- Update to multitail-3.4.7
* Tue Feb 22 2005 oc2pus@arcor.de 3.4.6-0.oc2pus.1
- Update to multitail-3.4.6
* Thu Jan 20 2005 oc2pus@arcor.de 3.4.5-0.oc2pus.1
- Update to multitail-3.4.5
* Sun Jan 16 2005 oc2pus@arcor.de 3.4.4-0.oc2pus.1
- Update to multitail-3.4.4
* Sat Dec 25 2004 oc2pus@arcor.de 3.4.3-0.oc2pus.1
- Update to multitail-3.4.3
* Fri Dec 24 2004 oc2pus@arcor.de 3.4.2-0.oc2pus.2
- build for SuSE-9.2
* Sat Nov 27 2004 oc2pus@arcor.de 3.4.2-0.oc2pus.1
- Update to multitail-3.4.2
* Sun Oct 31 2004 oc2pus@arcor.de 3.4.1-0.oc2pus.1
- Update to multitail-3.4.1
* Mon Oct 18 2004 oc2pus@arcor.de 3.4.0-0.oc2pus.1
- Update to multitail-3.4.0
* Sun Oct 17 2004 oc2pus@arcor.de 3.3.8-0.oc2pus.1
- Update to multitail-3.3.8
* Tue Oct  5 2004 oc2pus@arcor.de 3.3.7-0.oc2pus.1
- Update to multitail-3.3.7
- based on SuSE-spec Wed Feb 18 2004 - mmj@suse.de
